==> sfml-2.6.1-1-aarch64.pkg.tar.xz: usr/share/doc/SFML/html/search/functions_3.js <==
var searchData=
[
  ['decode_0',['decode',['../classsf_1_1Utf_3_0116_01_4.html#a17be6fc08e51182e7ac8bf9269dfae37',1,'sf::Utf&lt; 16 &gt;::decode()'],['../classsf_1_1Utf_3_0132_01_4.html#ad754ce8476f7b80563890dec12cefd46',1,'sf::Utf&lt; 32 &gt;::decode()'],['../classsf_1_1Utf_3_018_01_4.html#a59d4e8d5832961e62b263d308b72bf4b',1,'sf::Utf&lt; 8 &gt;::decode()']]],
  ['decodeansi_1',['decodeAnsi',['../classsf_1_1Utf_3_0132_01_4.html#a68346ea833f88267a7c739d4d96fb86f',1,'sf::Utf&lt; 32 &gt;']]],
  ['decodewide_2',['decodeWide',['../classsf_1_1Utf_3_0132_01_4.html#a043fe25f5f4dbc205e78e6f1d99840dc',1,'sf::Utf&lt; 32 &gt;']]],
  ['deletedirectory_3',['deleteDirectory',['../classsf_1_1Ftp.html#a2a8a7ef9144204b5b319c9a4be8806c2',1,'sf::Ftp']]],
  ['deletefile_4',['deleteFile',['../classsf_1_1Ftp.html#a8aa272b0eb7769a850006e70fcad370f',1,'sf::Ftp']]],
  ['delocalize_5',['delocalize',['../classsf_1_1Keyboard.html#af9fd530c73b8a2cd6094d373e879eb00',1,'sf::Keyboard']]],
  ['directoryresponse_6',['DirectoryResponse',['../classsf_1_1Ftp_1_1DirectoryResponse.html#a36b6d2728fa53c4ad37b7a6307f4d388',1,'sf::Ftp::DirectoryResponse']]],
  ['disconnect_7',['disconnect',['../classsf_1_1Ftp.html#acf7459926f3391cd06bf84337ed6a0f4',1,'sf::Ftp::disconnect()'],['../classsf_1_1TcpSocket.html#ac18f518a9be3d6be5e74b9404c253c1e',1,'sf::TcpSocket::disconnect()']]],
  ['display_8',['display',['../classsf_1_1RenderTexture.html#af92886d5faef3916caff9fa9ab32c555',1,'sf::RenderTexture::display()'],['../classsf_1_1Window.html#adabf839cb103ac96cfc82f781638772a',1,'sf::Window::display()']]],
  ['download_9',['download',['../classsf_1_1Ftp.html#a20c1600ec5fd6f5a2ad1429ab8aa5df4',1,'sf::Ftp']]],
  ['draw_10',['draw',['../classsf_1_1Drawable.html#a90d2c88bba9b035a0844eccb380ef631',1,'sf::Drawable::draw()'],['../classsf_1_1RenderTarget.html#a12417a3bcc245c41d957b29583556f39',1,'sf::RenderTarget::draw(const Drawable &amp;drawable, const RenderStates &amp;states=RenderStates::Default)'],['../classsf_1_1RenderTarget.html#a976bc94057799eb9f8a18ac5fdfd9b73',1,'sf::RenderTarget::draw(const Vertex *vertices, std::size_t vertexCount, PrimitiveType type, const RenderStates &amp;states=RenderStates::Default)'],['../classsf_1_1RenderTarget.html#a3dc4d06f081d36ca1e8f1a1298d49abc',1,'sf::RenderTarget::draw(const VertexBuffer &amp;vertexBuffer, const RenderStates &amp;states=RenderStates::Default)'],['../classsf_1_1RenderTarget.html#a07cb25d4557a30146b24b25b242310ea',1,'sf::RenderTarget::draw(const VertexBuffer &amp;vertexBuffer, std::size_t firstVertex, std::size_t vertexCount, const RenderStates &amp;states=RenderStates::Default)']]]
];

==> sfml-2.6.2-1-aarch64.pkg.tar.xz: usr/share/doc/SFML/html/search/functions_3.js <==
var searchData=
[
  ['decode_0',['decode',['../classsf_1_1Utf_3_018_01_4.html#a59d4e8d5832961e62b263d308b72bf4b',1,'sf::Utf&lt; 8 &gt;::decode()'],['../classsf_1_1Utf_3_0116_01_4.html#a17be6fc08e51182e7ac8bf9269dfae37',1,'sf::Utf&lt; 16 &gt;::decode()'],['../classsf_1_1Utf_3_0132_01_4.html#ad754ce8476f7b80563890dec12cefd46',1,'sf::Utf&lt; 32 &gt;::decode(In begin, In end, Uint32 &amp;output, Uint32 replacement=0)']]],
  ['decodeansi_1',['decodeAnsi',['../classsf_1_1Utf_3_0132_01_4.html#a68346ea833f88267a7c739d4d96fb86f',1,'sf::Utf&lt; 32 &gt;']]],
  ['decodewide_2',['decodeWide',['../classsf_1_1Utf_3_0132_01_4.html#a043fe25f5f4dbc205e78e6f1d99840dc',1,'sf::Utf&lt; 32 &gt;']]],
  ['deletedirectory_3',['deleteDirectory',['../classsf_1_1Ftp.html#a2a8a7ef9144204b5b319c9a4be8806c2',1,'sf::Ftp']]],
  ['deletefile_4',['deleteFile',['../classsf_1_1Ftp.html#a8aa272b0eb7769a850006e70fcad370f',1,'sf::Ftp']]],
  ['delocalize_5',['delocalize',['../classsf_1_1Keyboard.html#af9fd530c73b8a2cd6094d373e879eb00',1,'sf::Keyboard']]],
  ['directoryresponse_6',['DirectoryResponse',['../classsf_1_1Ftp_1_1DirectoryResponse.html#a36b6d2728fa53c4ad37b7a6307f4d388',1,'sf::Ftp::DirectoryResponse']]],
  ['disconnect_7',['disconnect',['../classsf_1_1Ftp.html#acf7459926f3391cd06bf84337ed6a0f4',1,'sf::Ftp::disconnect()'],['../classsf_1_1TcpSocket.html#ac18f518a9be3d6be5e74b9404c253c1e',1,'sf::TcpSocket::disconnect()']]],
  ['display_8',['display',['../classsf_1_1RenderTexture.html#af92886d5faef3916caff9fa9ab32c555',1,'sf::RenderTexture::display()'],['../classsf_1_1Window.html#adabf839cb103ac96cfc82f781638772a',1,'sf::Window::display()']]],
  ['download_9',['download',['../classsf_1_1Ftp.html#a20c1600ec5fd6f5a2ad1429ab8aa5df4',1,'sf::Ftp']]],
  ['draw_10',['draw',['../classsf_1_1Drawable.html#a90d2c88bba9b035a0844eccb380ef631',1,'sf::Drawable::draw()'],['../classsf_1_1RenderTarget.html#a12417a3bcc245c41d957b29583556f39',1,'sf::RenderTarget::draw(const Drawable &amp;drawable, const RenderStates &amp;states=RenderStates::Default)'],['../classsf_1_1RenderTarget.html#a976bc94057799eb9f8a18ac5fdfd9b73',1,'sf::RenderTarget::draw(const Vertex *vertices, std::size_t vertexCount, PrimitiveType type, const RenderStates &amp;states=RenderStates::Default)'],['../classsf_1_1RenderTarget.html#a3dc4d06f081d36ca1e8f1a1298d49abc',1,'sf::RenderTarget::draw(const VertexBuffer &amp;vertexBuffer, const RenderStates &amp;states=RenderStates::Default)'],['../classsf_1_1RenderTarget.html#a07cb25d4557a30146b24b25b242310ea',1,'sf::RenderTarget::draw(const VertexBuffer &amp;vertexBuffer, std::size_t firstVertex, std::size_t vertexCount, const RenderStates &amp;states=RenderStates::Default)']]]
];
